#!/usr/bin/python
# -*- coding: utf-8 -*-
'''
Created on 09.07.2010

@author: adm
'''

import yaml
import logging
import logging.config

from artixds.domain import DiscountSystem, DiscountCampaign
from subsystem import Subsystem
from dao import loadDiscountSystem
from dao import session
from dao import getDiscountUpdateTime

try:
    logging.config.fileConfig('/linuxcash/cash/discountsystems/logging.properties')
except Exception, e:
    print u'logger configure error: `%s`' % e
    logging.basicConfig()

discountSystem, secondDiscountSystem, bonusEarnSystem, bonusLimitSystem = DiscountSystem(), DiscountSystem(), DiscountSystem(), DiscountSystem()
time_update = loadDiscountSystem(session, discountSystem, secondDiscountSystem, bonusEarnSystem, bonusLimitSystem)

log = logging.getLogger("su.artix.dm")

log.debug(u'Первая дисконтная система:')
for n, line in enumerate(filter(lambda x: x.rstrip(), yaml.dump(discountSystem).split('\n'))):
    log.debug(u'%4d: %s' % (n, line.rstrip()))
log.debug(u'Вторая дисконтная система:')
for n, line in enumerate(filter(lambda x: x.rstrip(), yaml.dump(secondDiscountSystem).split('\n'))):
    log.debug(u'%4d: %s' % (n, line.rstrip()))
log.debug(u'Начисление бонусов:')
for n, line in enumerate(filter(lambda x: x.rstrip(), yaml.dump(bonusEarnSystem).split('\n'))):
    log.debug(u'%4d: %s' % (n, line.rstrip()))
log.debug(u'Списание бонусов:')
for n, line in enumerate(filter(lambda x: x.rstrip(), yaml.dump(bonusLimitSystem).split('\n'))):
    log.debug(u'%4d: %s' % (n, line.rstrip()))

def refreshSystems():
    global time_update
    global manualCampaigns
    old_time_update = time_update
    log.debug(u'Обновление дисконтной системы')
    time_update = loadDiscountSystem(session, discountSystem, secondDiscountSystem, bonusEarnSystem, bonusLimitSystem, time_update)
    return old_time_update != time_update

def isUpToDate():
    global time_update
    return time_update != None and getDiscountUpdateTime(session) == time_update

def calculateDiscountImpact(priority):
    return Subsystem(discountSystem).getJsonImpacts(artix_core_check, priority, True)

def calculateSecondDiscountImpact(priority):
    return Subsystem(secondDiscountSystem).getJsonImpacts(artix_core_check, priority, True)

def calculateBonusEarningsImpact():
    return Subsystem(bonusEarnSystem).getJsonImpacts(artix_core_check)

def calculateBonusLimitImpact():
    return Subsystem(bonusLimitSystem).getJsonImpacts(artix_core_check)

def getCampaigns():
    return Subsystem().encode(discountSystem.manualCampaigns)

def getSecondDiscountSystemCampaigns():
    return Subsystem().encode(secondDiscountSystem.manualCampaigns)

def getGroupAndCampaignsPriorities():
    return Subsystem().encode(discountSystem.groupsAndCampaignsPriorities)

def getSecondDiscountSystemGroupAndCampaignsPriorities():
    return Subsystem().encode(secondDiscountSystem.groupsAndCampaignsPriorities)

def calculateDiscountImpacts(qualifiers):
    subsystem = Subsystem(discountSystem)
    filters = [lambda campaign: {qualifiers}.issubset(campaign.qualifiers)]
    subsystem.setQualifiersFilters(filters)
    return subsystem.getJsonImpacts(artix_core_check)

def calculateLifeTimeLimit(data):
    try:
        campaign = yaml.load(data)
        campaign.calcAssetDates()
        return { "assetBeginDate": campaign.assetBeginDate, "assetEndDate": campaign.assetEndDate, "id": campaign.id, "weight": campaign.weight }
    except Exception as e:
        log.warn('%s', str(e))
    return {}
